# from tkinter import *
# import os
# from tkinter import ttk
# import tkinter as tk
# from tkinter import filedialog
# from PIL import ImageTk, Image





# class Automation:
#     def __init__(self,root):
#         self.root=root
#         self.root.title("AIUTGen")
#         self.root.geometry("1020x500")
#         self.filetreeview = ttk.Treeview(self.root, show='tree')
#         self.filetreeview.place(x=7,y=180,width=180)
#         self.filetreeview.bind("<ButtonRelease-1>", self.on_treeview_select) 
#         btnload = ttk.Button(self.root, command=self.open_file_dialog, text="Select Source", width=20,compound=tk.LEFT)
#         btnload.place(x=40, y=120)
#         global lblFunction
#         lblFunction=ttk.Label(self.root,text="Source Code",foreground="blue")
#         lblFunction.place(x=200,y=190)
        
#         self.function=Text(self.root,font=("MS Sans Serif",10),width=55,height=15)
#         self.function.place(x=200, y=210)

#         file_img = """
# iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAIAAACQkWg2AAAABGdB
# TUEAALGPC/xhBQAAAAlwSFlzAAAScwAAEnMBjCK5BwAAAalJREFU
# OE99kUtLAmEUhg38Af6a6he06SJIF8FFREVtqkVEkBB2IcJIRDAk
# 80KrNq3CWihuuuh4GVIwM9BSa0bHUXGc8X7p1Bc6jtLLxzAwz3Pm
# nPMNcaWySCR6CYVoOgMvzWaz3W63Wq1GowFPsVg8PDIqkUjg019A
# gEOSJHAowEHAhDidzmAwGI3FEPZTXSDwafiJ3W5nWRbH8TSVGSAI
# aBDi8TiGYT6fz2QyCwU+Dc0ADanX67XfWK3W/4QOjYRqtWqxWIQC
# mhKh/NpAVyoVs/GcclwzabI7NF/odILocrnsPFwvGRcS6uUeob8T
# RDOxMGuYz2vkfsdtVxhIg1AqMqnTRUYrD+iU2Vy+R+jvBMpTN+aC
# Zi6umo2+RXouDmgkFJ4fyLNNNvUFdJFM0kfTuQOpfk9ZZLmuQBBE
# Z4Np/VrtapVSKwqf7wmlLLc/iR9vGAyGnrWCgC4ImmZpKqVbKeoV
# xK4sq5pI7kgjAfzCZBIK/PWX8jRxspRVjVPbY8FLLcdxfQKZ8vlx
# j9eLebxuzOPGMO/j/YdyJro1dWezPblc4defieF8A+ZBma193+p6
# AAAAAElFTkSuQmCC
# """
#         dir_img = """
# iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAIAAACQkWg2AAAABGdB
# TUEAALGPC/xhBQAAAAlwSFlzAAAScgAAEnIBXmVb4wAAAihJREFU
# OE990vtv0kAcAPDh4wd/8w/yp5n4i4kkmizoBMKcRIfG7YepWSSZ
# MSTGSXQao8wtjIw5ZkJEJ4+O0CGvoWhSCmw0sFJaHoU+GEJbyDax
# EwMjQS+Xy30v97m7791JOF4Y+FMOBEJsj508PXD8lERyoj3Yp4ig
# XclNRSlyg0F0TFxLRbXFyAMqaarkQrXabmfO4eqdoBRWtgQnujGM
# +DRVbIYnTU3Wvrf7hcubGRToTOsFvK3V/JZyy6KeCXL7CZc3CEVj
# k7bTO85/A+FDgwr6rKNIQEtu6XnC0Ch/+j+wCSXXulke994vxh/X
# sNkGaaXTfXfYVLbEIwk2gbQBpstxz0QOmq6mdXxxmUr1A8Wg4i8o
# rLoWh2C3hvhxr5KcqhMLVMrRJ4eCX97irL/qFh6fdxkvQoAaj4yz
# iTv17KsyYu8D8t7hg+q7fXahjr50GaWQawT7OkbDN3/u6JIflQxb
# qXN8zzsQniv7tGGv9Czx/tz64gXIqcTCagoaqWxpcO/dKBzL4oTI
# uu+QBYaaBX2DeBgyDoJmKQzIMyEVE5Wz8HXMO7W29tnnD8TiiS5A
# HbIGPi1kJn3zZzdWLh2CoIKGZHRUlXJPzs29XVoy40SuC6p0lgyo
# +PS4e/aM8835GHALDWvY2LVybAxcVs881XtAUEyjC8SEGPx7bfu2
# 4/mgzfwiEgSz4dcJixRxjq5YVtEM1r6oHiDGuP9RwHS1TOaP/tCj
# /d+VL1STn8NNZQAAAABJRU5ErkJggg==
# """
#         global file_image,dir_image
#         file_image= PhotoImage(data=file_img)
#         dir_image = PhotoImage(data=dir_img)
#         # file_image = Image.open(f"java.png")
#         # dir_image = Image.open(f"folder_icon.png")
#         # file_image = file_image.resize((18, 18), Image.ANTIALIAS if hasattr(Image, 'ANTIALIAS') else Image.BICUBIC)
#         # dir_image = dir_image.resize((18, 18), Image.ANTIALIAS if hasattr(Image, 'ANTIALIAS') else Image.BICUBIC)
#     def on_treeview_select(self, event):
#         print("inside on_treeview_select")
#         item = self.filetreeview.selection()[0]
#         item_text = self.filetreeview.item(item, "text")
#         item_path = os.path.join(self.get_folder_path(item), item_text)
#         print(item_path)
#         if os.path.isfile(item_path):
#             with open(item_path, 'r') as file:
#                 content = file.read()
#                 self.function.delete("1.0", "end")
#                 self.function.insert("end", content)

#     def get_folder_path(self, item):
#         # Helper method to get the folder path of an item in the treeview
#         print("inside get_folder_path")
#         parent = self.filetreeview.parent(item)
#         if parent == '':
#             return ""
#         else:
#             return os.path.join(self.get_folder_path(parent), self.filetreeview.item(parent, "text"))

#     def open_file_dialog(self):
#         src_folder_path = None
#         src_folder_path = filedialog.askdirectory(title="Select the Source Code Location")
#         start_path = os.path.expanduser(src_folder_path)
#         start_dir_entries = os.listdir(start_path)
#         parent_iid = self.filetreeview.insert(parent='',
#                              index='0',
#                              text=src_folder_path,
#                              open=True,
#                              image=dir_image)
#         self.new_folder(parent_path=start_path,
#            directory_entries=start_dir_entries,
#            parent_iid=parent_iid,
#            f_image=file_image,
#            d_image=dir_image)
#         print(src_folder_path)
#     def new_folder(self,parent_path, directory_entries,
#                parent_iid, f_image, d_image):
#          for name in directory_entries:
#             item_path = parent_path+os.sep+name
#             if os.path.isdir(item_path):
#                 subdir_iid = self.filetreeview.insert(parent=parent_iid,index='end',
#                                          text=name,
#                                          image=d_image)
#                 try:
#                     subdir_entries = os.listdir(item_path)
#                     self.new_folder(parent_path=item_path,
#                            directory_entries=subdir_entries,
#                            parent_iid=subdir_iid,
#                            f_image=f_image,
#                            d_image=d_image)
#                 except PermissionError:
#                     pass
#             else:
#                 self.filetreeview.insert(parent=parent_iid,
#                             index='end',
#                             text=name,
#                             image=f_image)
#             print(item_path)
           


# if __name__=="__main__":
#     root=Tk()
#     obj=Automation(root)
#     root.mainloop()





from tkinter import *
import os
from tkinter import ttk
import tkinter as tk
from tkinter import filedialog
from PIL import Image, ImageTk

class Automation:
    def __init__(self, root):
        self.root = root
        self.root.title("AIUTGen")
        self.root.geometry("1020x500")

        self.filetreeview = ttk.Treeview(self.root, show='tree')
        self.filetreeview.place(x=7, y=180, width=180)
        self.filetreeview.bind("<ButtonRelease-1>", self.on_treeview_select) 

        btnload = ttk.Button(self.root, command=self.open_file_dialog, text="Select Source", width=20, compound=tk.LEFT)
        btnload.place(x=40, y=120)

        global lblFunction
        lblFunction = ttk.Label(self.root, text="Source Code", foreground="blue")
        lblFunction.place(x=200, y=190)

        self.function = Text(self.root, font=("MS Sans Serif", 10), width=55, height=15)
        self.function.place(x=200, y=210)

        self.file_image = Image.open("java.png")  # Change the image file name
        self.dir_image = Image.open("folder_icon.png")  # Change the image file name

        self.file_image = self.file_image.resize((18, 18), Image.ANTIALIAS if hasattr(Image, 'ANTIALIAS') else Image.BICUBIC)
        self.dir_image = self.dir_image.resize((18, 18), Image.ANTIALIAS if hasattr(Image, 'ANTIALIAS') else Image.BICUBIC)

        self.file_image = ImageTk.PhotoImage(self.file_image)
        self.dir_image = ImageTk.PhotoImage(self.dir_image)
        self.image_dict = {
            ".java": "java.png",
            ".cs": "cs.png",
            ".py": "py.png",
            ".dir": "folder_icon.png",
            # Add more file extensions and corresponding image paths as needed
        }
        self.load_images()
    def load_images(self):
        for ext, path in self.image_dict.items():
            image = Image.open(path)
            image = image.resize((18, 18), Image.ANTIALIAS if hasattr(Image, 'ANTIALIAS') else Image.BICUBIC)
            self.image_dict[ext] = ImageTk.PhotoImage(image)
    def new_folder(self, parent_path, directory_entries, parent_iid, d_image):
        for name in directory_entries:
            item_path = os.path.join(parent_path, name)
            if os.path.isdir(item_path):
                subdir_iid = self.filetreeview.insert(parent=parent_iid, index='end',
                                         text=name,
                                         image=d_image)
                try:
                    subdir_entries = os.listdir(item_path)
                    self.new_folder(parent_path=item_path,
                           directory_entries=subdir_entries,
                           parent_iid=subdir_iid,
                           d_image=d_image)
                except PermissionError:
                    pass
            else:
                file_extension = os.path.splitext(name)[1].lower()
                file_image = self.get_file_image(file_extension)
                self.filetreeview.insert(parent=parent_iid,
                            index='end',
                            text=name,
                            image=file_image)

    def get_file_image(self, file_extension):
        # Helper method to get the image based on the file extension
        return self.image_dict.get(file_extension, self.image_dict[".dir"])


    def on_treeview_select(self, event):
        print("inside on_treeview_select")
        item = self.filetreeview.selection()[0]
        item_text = self.filetreeview.item(item, "text")
        item_path = os.path.join(self.get_folder_path(item), item_text)
        print(item_path)
        if os.path.isfile(item_path):
            with open(item_path, 'r') as file:
                content = file.read()
                self.function.delete("1.0", "end")
                self.function.insert("end", content)

    def get_folder_path(self, item):
        # Helper method to get the folder path of an item in the treeview
        print("inside get_folder_path")
        parent = self.filetreeview.parent(item)
        if parent == '':
            return ""
        else:
            return os.path.join(self.get_folder_path(parent), self.filetreeview.item(parent, "text"))

    def open_file_dialog(self):
        src_folder_path = None
        src_folder_path = filedialog.askdirectory(title="Select the Source Code Location")
        start_path = os.path.expanduser(src_folder_path)
        start_dir_entries = os.listdir(start_path)
        parent_iid = self.filetreeview.insert(parent='',
                             index='0',
                             text=src_folder_path,
                             open=True,
                             image=self.dir_image)
        self.new_folder(parent_path=start_path,
           directory_entries=start_dir_entries,
           parent_iid=parent_iid,
           f_image=self.file_image,
           d_image=self.dir_image)
        print(src_folder_path)

    # def new_folder(self, parent_path, directory_entries, parent_iid, f_image, d_image):
    #      for name in directory_entries:
    #         item_path = os.path.join(parent_path, name)
    #         if os.path.isdir(item_path):
    #             subdir_iid = self.filetreeview.insert(parent=parent_iid, index='end',
    #                                      text=name,
    #                                      image=d_image)
    #             try:
    #                 subdir_entries = os.listdir(item_path)
    #                 self.new_folder(parent_path=item_path,
    #                        directory_entries=subdir_entries,
    #                        parent_iid=subdir_iid,
    #                        f_image=f_image,
    #                        d_image=d_image)
    #             except PermissionError:
    #                 pass
    #         else:
    #             self.filetreeview.insert(parent=parent_iid,
    #                         index='end',
    #                         text=name,
    #                         image=f_image)
    #         print(item_path)

if __name__ == "__main__":
    root = Tk()
    obj = Automation(root)
    root.mainloop()



# from tkinter import *
# import os
# from tkinter import ttk
# import tkinter as tk
# from tkinter import filedialog
# from PIL import Image, ImageTk

# class Automation:
#     def __init__(self, root):
#         self.root = root
#         self.root.title("AIUTGen")
#         self.root.geometry("1020x500")

#         self.filetreeview = ttk.Treeview(self.root, show='tree')
#         self.filetreeview.place(x=7, y=180, width=180)
#         self.filetreeview.bind("<ButtonRelease-1>", self.on_treeview_select)

#         btnload = ttk.Button(self.root, command=self.open_file_dialog, text="Select Source", width=20, compound=tk.LEFT)
#         btnload.place(x=40, y=120)

#         global lblFunction
#         lblFunction = ttk.Label(self.root, text="Source Code", foreground="blue")
#         lblFunction.place(x=200, y=190)

#         self.function = Text(self.root, font=("MS Sans Serif", 10), width=55, height=15)
#         self.function.place(x=200, y=210)

#         self.image_dict = {
#             ".java": "java.png",
#             ".cs": "cs.png",
#             ".py": "py.png",
#             ".dir": "folder_icon.png",
#             # Add more file extensions and corresponding image paths as needed
#         }

#         # Initialize image variables
#         self.file_image = self.get_file_image(".java")  # Choose an initial file extension
#         self.dir_image = self.get_file_image(".dir")

#         self.load_images()

#     def load_images(self):
#         for ext in self.image_dict:
#             self.image_dict[ext] = self.get_file_image(ext)

#     def new_folder(self, parent_path, directory_entries, parent_iid, d_image):
#         for name in directory_entries:
#             item_path = os.path.join(parent_path, name)
#             if os.path.isdir(item_path):
#                 subdir_iid = self.filetreeview.insert(parent=parent_iid, index='end',
#                                          text=name,
#                                          image=d_image)
#                 try:
#                     subdir_entries = os.listdir(item_path)
#                     self.new_folder(parent_path=item_path,
#                            directory_entries=subdir_entries,
#                            parent_iid=subdir_iid,
#                            d_image=d_image)
#                 except PermissionError:
#                     pass
#             else:
#                 file_extension = os.path.splitext(name)[1].lower()
#                 file_image = self.get_file_image(file_extension)
#                 self.filetreeview.insert(parent=parent_iid,
#                             index='end',
#                             text=name,
#                             image=file_image)

#     def get_file_image(self, file_extension):
#         # Helper method to get the image based on the file extension
#         image_path = self.image_dict.get(file_extension, self.image_dict[".dir"])
#         return ImageTk.PhotoImage(Image.open(image_path))

#     def on_treeview_select(self, event):
#         print("inside on_treeview_select")
#         item = self.filetreeview.selection()[0]
#         item_text = self.filetreeview.item(item, "text")
#         item_path = os.path.join(self.get_folder_path(item), item_text)
#         print(item_path)
#         if os.path.isfile(item_path):
#             with open(item_path, 'r') as file:
#                 content = file.read()
#                 self.function.delete("1.0", "end")
#                 self.function.insert("end", content)

#     def get_folder_path(self, item):
#         # Helper method to get the folder path of an item in the treeview
#         print("inside get_folder_path")
#         parent = self.filetreeview.parent(item)
#         if parent == '':
#             return ""
#         else:
#             return os.path.join(self.get_folder_path(parent), self.filetreeview.item(parent, "text"))

#     def open_file_dialog(self):
#         src_folder_path = None
#         src_folder_path = filedialog.askdirectory(title="Select the Source Code Location")
#         start_path = os.path.expanduser(src_folder_path)
#         start_dir_entries = os.listdir(start_path)
#         parent_iid = self.filetreeview.insert(parent='',
#                              index='0',
#                              text=src_folder_path,
#                              open=True,
#                              image=self.dir_image)
#         self.new_folder(parent_path=start_path,
#            directory_entries=start_dir_entries,
#            parent_iid=parent_iid,
#            d_image=self.dir_image)
#         print(src_folder_path)

# if __name__ == "__main__":
#     root = Tk()
#     obj = Automation(root)
#     root.mainloop()



from tkinter import *
import os
from tkinter import ttk
import tkinter as tk
from tkinter import filedialog
from PIL import Image, ImageTk

class Automation:
    def __init__(self, root):
        self.root = root
        self.root.title("AIUTGen")
        self.root.geometry("1020x500")

        self.filetreeview = ttk.Treeview(self.root, show='tree')
        self.filetreeview.place(x=7, y=180, width=180)
        self.filetreeview.bind("<ButtonRelease-1>", self.on_treeview_select) 
        self.filetreeview.bind("<Button-3>", self.show_context_menu)  # Bind right-click event

        btnload = ttk.Button(self.root, command=self.open_file_dialog, text="Select Source", width=20, compound=tk.LEFT)
        btnload.place(x=40, y=120)

        global lblFunction
        lblFunction = ttk.Label(self.root, text="Source Code", foreground="blue")
        lblFunction.place(x=200, y=190)

        self.function = Text(self.root, font=("MS Sans Serif", 10), width=55, height=15)
        self.function.place(x=200, y=210)

        self.image_dict = {
            ".java": "java.png",
            ".cs": "cs.png",
            ".py": "py.png",
            ".dir": "folder_icon.png",
            # Add more file extensions and corresponding image paths as needed
        }
        self.load_images()

    def load_images(self):
        self.image_dict = {ext: Image.open(path).resize((18, 18), Image.ANTIALIAS if hasattr(Image, 'ANTIALIAS') else Image.BICUBIC) for ext, path in self.image_dict.items()}
        self.image_dict = {ext: ImageTk.PhotoImage(image) for ext, image in self.image_dict.items()}

        # Load folder icon separately
        folder_icon_path = "folder_icon.png"
        self.dir_image = Image.open(folder_icon_path).resize((18, 18), Image.ANTIALIAS if hasattr(Image, 'ANTIALIAS') else Image.BICUBIC)
        self.dir_image = ImageTk.PhotoImage(self.dir_image)
    def new_folder(self, parent_path, directory_entries, parent_iid, d_image):
        for name in directory_entries:
            item_path = os.path.join(parent_path, name)
            if os.path.isdir(item_path):
                subdir_iid = self.filetreeview.insert(parent=parent_iid, index='end',
                                         text=name,
                                         image=d_image)
                try:
                    subdir_entries = os.listdir(item_path)
                    self.new_folder(parent_path=item_path,
                           directory_entries=subdir_entries,
                           parent_iid=subdir_iid,
                           d_image=d_image)
                except PermissionError:
                    pass
            else:
                file_extension = os.path.splitext(name)[1].lower()
                file_image = self.get_file_image(file_extension)
                self.filetreeview.insert(parent=parent_iid,
                            index='end',
                            text=name,
                            image=file_image)

    def get_file_image(self, file_extension):
        # Helper method to get the image based on the file extension
        return self.image_dict.get(file_extension, self.dir_image)

    def on_treeview_select(self, event):
        print("inside on_treeview_select")
        item = self.filetreeview.selection()[0]
        item_text = self.filetreeview.item(item, "text")
        item_path = os.path.join(self.get_folder_path(item), item_text)
        print(item_path)
        if os.path.isfile(item_path):
            with open(item_path, 'r') as file:
                content = file.read()
                self.function.delete("1.0", "end")
                self.function.insert("end", content)

    def get_folder_path(self, item):
        # Helper method to get the folder path of an item in the treeview
        print("inside get_folder_path")
        parent = self.filetreeview.parent(item)
        if parent == '':
            return ""
        else:
            return os.path.join(self.get_folder_path(parent), self.filetreeview.item(parent, "text"))


    def open_file_dialog(self):
        src_folder_path = filedialog.askdirectory(title="Select the Source Code Location")
        start_path = os.path.expanduser(src_folder_path)
        start_path = os.path.expanduser(src_folder_path)
        start_dir_entries = os.listdir(start_path)
        parent_iid = self.filetreeview.insert(parent='',
                             index='0',
                             text=src_folder_path,
                             open=True,
                             image=self.dir_image)
        self.new_folder(parent_path=start_path,
           directory_entries=start_dir_entries,
           parent_iid=parent_iid,
           d_image=self.dir_image)

    def show_context_menu(self, event):
        # Display context menu when right-clicking on an item in the treeview
        item = self.filetreeview.selection()[0]
        item_text = self.filetreeview.item(item, "text")
        item_path = os.path.join(self.get_folder_path(item), item_text)

        menu = Menu(self.root, tearoff=0)
        menu.add_command(label="Generate Test Case", command=lambda: self.generate_test_case_handler(item_path))
        menu.post(event.x_root, event.y_root)

    def generate_test_case_handler(self, file_path):
        # Placeholder for the actual test case generation code
        print(f"Generate Test Case for: {file_path}")

if __name__ == "__main__":
    root = Tk()
    obj = Automation(root)
    root.mainloop()



import os
import subprocess
from openai import AzureOpenAI
from configparser import ConfigParser
from time import perf_counter

MODEL_TEMP = 0.7
MAX_TOKENS = 5000
RESULT_SUCCESS = "TEST Case Generated"
RESULT_ERROR = ""
# GPT-4	8K	$0.03/1000Tokens Prompt	$0.06/1000 Tokens Completion
# Prompt would be what you send to the chat completion model, and completion would be the output that is sent back.
# So think of it as �Prompt=input/question� �Completion=output/answer�
RATE_PROMPT = 0.03 # Per 1000 Token
RATE_COMPLETION = 0.06 # Per 1000 Token

class utils():
    def __init__(self):
        pass

    def cient(self, client):
        self.__client = client

    def client(self):
        return self.__client

    def api_end_point(self, api_end_point):
        self.__api_end_point = api_end_point

    def api_end_point(self):
        return self.__api_end_point

    def api_key(self, api_key):
        self.__api_key = api_key

    def api_key(self):
        return self.__api_key

    def api_version(self, api_version):
        self.__api_version = api_version

    def api_version(self):
        return self.__api_version

    def model_deployment_name(self, model_deployment_name):
        self.__model_deployment_name = model_deployment_name

    def model_deployment_name(self):
        return self.__model_deployment_name

    def src_files_location(self, src_files_location):
        self.__src_files_location = src_files_location

    def src_files_location(self):
        return self.__src_files_location

    def dest_test_files_location(self, dest_test_files_location):
        self.__dest_test_files_location = dest_test_files_location

    def dest_test_files_location(self):
        return self.__dest_test_files_location

    def code_base_location(self, code_base_location):
        self.__code_base_location = code_base_location

    def code_base_location(self):
        return self.__code_base_location

    def unit_test_framework(self, unit_test_framework):
        self.__unit_test_framework = unit_test_framework

    def unit_test_framework(self):
        return self.__unit_test_framework

    def src_file_name(self, src_file_name):
        self.__src_file_name = src_file_name

    def src_file_name(self):
        return self.__src_file_name

    def src_file_location(self, src_file_location):
        self.__src_file_location = src_file_location

    def src_file_location(self):
        return self.__src_file_location

    def test_file_name(self, test_file_name):
        self.__test_file_name = test_file_name

    def test_file_name(self):
        return self.__test_file_name

    def test_file_location(self, test_file_location):
        self.__test_file_location = test_file_location

    def test_file_location(self):
        return self.__test_file_location

    def read_config(self):
        try:
            configur = ConfigParser()
            configur.read('UT_Settings.ini')
            self.api_end_point = configur.get('Default','azure_endpoint')
            self.api_key = configur.get('Default','api_key')
            self.api_version = configur.get('Default','api_version')
            self.model_deployment_name = configur.get('Default','model_deployment_name')
            self.dest_test_files_location = configur.get('Java','dest_test_files_location')
            self.code_base_location = configur.get('Java','code_base_location')

            if self.dest_test_files_location[-1] != '\\':
                self.dest_test_files_location += '\\'

            if self.code_base_location[-1] != '\\':
                self.code_base_location += '\\'

            return True
        except Exception as err:
            print(err)
            return False

    def create_azure_connection(self):
        try:
            if (self.read_config()):
                self.client = AzureOpenAI(
                    azure_endpoint=self.api_end_point,
                    api_key=self.api_key,
                    api_version=self.api_version)
                return self.client
            else:
                return False
        except Exception as err:
            print(err)
            return False

def gen_no_of_tc(class_to_test, unit_test_framework):
    try:
        global NO_OF_TC
        global NO_OF_LARGE_TC
        count = 1
        for letter in class_to_test:

            if unit_test_framework.lower()=="junit":
                if letter == ';' or letter == "{":
                    count += 1

        NO_OF_TC = count // 10

        if count > 100:
            NO_OF_TC = count // 10
        else:
            NO_OF_TC = 10

        if count > 100:
            NO_OF_LARGE_TC = count // 100
        else:
            NO_OF_LARGE_TC = 1

        return True
    except Exception as err:
        print(err)
        return  False

def gen_prompt(class_to_test,unit_test_framework):
    try:
        global execute_messages
        execute_system_message = {}
        execute_user_message = {}
        if unit_test_framework.lower()=="junit":
            execute_system_message = {
                "role": "system",
                "content":
                    "You are a world-class developer with an eagle eye for unintended bugs and edge cases. You write careful, accurate unit tests. When asked to reply only with the language of the function, code, you write all of your code in a single block.",
            }
            execute_user_message = {
                "role": "user",
                "content":
                    f"""
                ```java
              {class_to_test}
              ```
              A good unit test suite should aim to:
              - Test the function's behavior for a wide range of possible inputs
              - Test edge cases that the author may not have foreseen
              - Take advantage of the features of `{unit_test_framework}` to make the tests easy to write and maintain
              - Be easy to read and understand, with clean code and descriptive names
              - Be deterministic, so that the tests always pass or fail in the same way.
              Using the required framework for that language, mentioning the framework used, write a suite of unit tests for the function, following the cases above. Also create an object of all the classes while generating test cases. Use <classname>.<function_name> before calling the function every time. If there's any class being created in the given program, include it in the generated program also and make sure to create an object of it in the test cases program as well. 
              All the import statements from the provided source to be added also in the generated program.
              Include helpful comments to explain each line. Reply only with code.
              Since you're using `{unit_test_framework}`, Use assertEquals to compare expected and result so include 1)import org.junit.Test; 2) import static org.junit.Assert.*; or both to compare the answers. 
              Make sure there are no syntax errors in the generated code. 
              Feel free to import any other packages that are used. 
              Ensure 100% Code Coverage, so include all unexpected edge cases also.
              Also create the test cases to cover the exceptions block added in provided code.
              Make sure there are no missed branches or lines while generating test cases. Ensure 100% cyclomatic complexity. Have at least {NO_OF_TC} test cases + unexpected edge cases and at least {NO_OF_LARGE_TC} large test case. 
              """,
            }
            execute_messages = [execute_system_message, execute_user_message]
            return True
    except Exception as err:
        print(err)
        return False

def read_src_file(objUtils, file):
    try:
        objUtils.src_file_location = file
        objUtils.src_file_name = file.split("\\")[-1]
        objFile = open(file, "r+")
        class_to_test = objFile.read()
        print(class_to_test)
        if (gen_no_of_tc(class_to_test, objUtils.unit_test_framework)):
            if(gen_prompt(class_to_test, objUtils.unit_test_framework)):
                return True
            else:
                return  False
        else:
            return False
    except Exception as err:
        print(err)
        return False

def create_testcase_file(objUtils, response):
    try:
        objUtils.test_file_name = objUtils.src_file_name
        code_in_response = ""
        testcase_file_name = ""
        for chunk in response.choices[0].message.content:
            code_in_response += chunk
            print(code_in_response)
        if objUtils.unit_test_framework.lower() == "junit":
            generated_code = code_in_response.split("```java")[1].split("```")[0].strip()
            classs = ""
            words = generated_code.split(" ")
            x = words.index("class")
            classs = words[x + 1]
            location = objUtils.dest_test_files_location
            #testcase_file_name = classs.strip() + ".java"
            testcase_file_name = objUtils.test_file_name
            location = location + testcase_file_name
            objUtils.test_file_location= location
            objUtils.test_file_name = testcase_file_name
            f = open(location, "w+")
            f.write(generated_code)
            f.close()
        return location, testcase_file_name
    except Exception as err:
        print(err)
        return False

def execute_test_cases(framework):
    response=""
    try:
        objUtils = utils()
        objUtils.read_config()
        if framework.lower() == "junit":
            command = "ant"
            str_find = "BUILD SUCCESSFUL"
            result = subprocess.run(command, shell=True, capture_output=True, text=True, cwd=objUtils.code_base_location)
            if str(result).find(str_find) > 0:
                #print("Command executed successfully.")
                #print("Output:")
                #print(result.stdout)

                # Open the HTML file in the default web browser
                subprocess.run("start index.html", shell=True, text=True,
                               cwd=objUtils.code_base_location + "report\\jacoco\\")
                response = [True, result.stdout]
            else:
                #print("Command execution failed.")
                #print("Error:")
                #print(result.stdout)
                response = [False, result.stdout]
    except Exception as err:
        print(err)
        response = [False, err]
    finally:
        return response

def calculate_price(token_in_prompt, token_in_completion):
    result = ((token_in_prompt * RATE_PROMPT) + (token_in_completion * RATE_COMPLETION)) / 1000
    print("Charges: $ " +str(round(result, 3)))
    return round(result, 3)

def generate_unit_cases(file_path, framework):
    try:
        t1_start = perf_counter()
        objUtils = utils()
        if objUtils.create_azure_connection():
            objUtils.unit_test_framework = framework
            read_src_file(objUtils,file_path)
            response = objUtils.client.chat.completions.create(
               model=objUtils.model_deployment_name,  # model = "deployment_name".
               messages=execute_messages,
               temperature=MODEL_TEMP,
               max_tokens=MAX_TOKENS
            )
            testcase_file_name = create_testcase_file(objUtils, response)
            t1_stop = perf_counter()

            elapsed_time_sec = t1_stop - t1_start
            elapsed_time_min = elapsed_time_sec / 60
            print("Elapsed time sec: ", round(elapsed_time_sec, 4))
            print("Elapsed time min: ", round(elapsed_time_min, 2))

            cost_testcase = calculate_price(response.usage.prompt_tokens, response.usage.completion_tokens)
            print(f"Metrics:"
                  f"Source File Name {objUtils.src_file_name}, "
                  f"Source File Path {objUtils.src_file_location}, "
                  f"Generated Test Case File {objUtils.test_file_name}, "
                  f"Generated Test Case File Path {objUtils.test_file_location}, "
                  f"Token sent in Prompt as request {response.usage.prompt_tokens}, "
                  f"Token received as response {response.usage.completion_tokens}, "
                  f"Total Tokens processed {response.usage.total_tokens},"
                  f"Open AI Cost USD {cost_testcase},"
                  f"Result {RESULT_SUCCESS}",
                  f"Elapsed Time {round(elapsed_time_min, 2)} minutes")
            metrics = f"{objUtils.src_file_name}," \
                  f"{objUtils.src_file_location}," \
                  f"{objUtils.test_file_name}," \
                  f"{objUtils.test_file_location}," \
                  f"{response.usage.prompt_tokens}," \
                  f"{response.usage.completion_tokens}," \
                  f"{response.usage.total_tokens}," \
                  f"$ {cost_testcase}," \
                  f"{RESULT_SUCCESS}," \
                  f"{round(elapsed_time_min, 2)}"
            return metrics
    except Exception as err:
        print(err)
        RESULT_ERROR = err
        metrics = f"{objUtils.src_file_name}, " \
                  f"{objUtils.src_file_location}, " \
                  f"{objUtils.test_file_name}, " \
                  f"{objUtils.test_file_location}, " \
                  f"{RESULT_ERROR}"
        return metrics



from setuptools import setup, find_packages

setup(
    name='AIUT_Tool',
    version='0.2.5',
    packages=find_packages(),
    install_requires=[
        'Pillow',
    ],
    entry_points={
        'console_scripts': [
            'AIUT_Tool=AIUT_Tool.AIUT:main',  
        ],
    },
    
    description='AIUT Tool - Automated Integration and Unit Testing',
   
    keywords='testing automation aiut',
  
   
)
